@@ -96,6 +96,8 @@ def run():
     global _verbosity
     global _interactive
 
+    #print("CLI run")
+
     _addConfigOptions()
 
     session = None
@@ -194,7 +196,7 @@ def init( opts = {} ):
 
     _addConfigOptions()
 
-    _capi = CommandLib.API( **opts )
+    _capi = CommandLib.API( opts )
     uid = _capi.getAuthUser()
     if uid:
         _uid = uid
@@ -656,12 +658,11 @@ def _dataCreate( title, alias, description, keywords, raw_data_file, extension,
 @click.option("-m","--metadata",type=str,required=False,help="Inline metadata in JSON format.")
 @click.option("-f","--metadata-file",type=str,required=False,help="Path to local metadata file containing JSON.")
 @click.option("-S","--metadata-set",is_flag=True,required=False,help="Set (replace) existing metadata with provided instead of merging.")
-@click.option("-C","--dep-clear",is_flag=True,help="Clear all dependencies on record. May be used in conjunction with --dep-add to replace existing dependencies.")
-@click.option("-A","--dep-add",multiple=True, nargs=2, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify new dependencies by listing first the type of relationship ('der', 'comp', or 'ver') follwed by ID/alias of the target record. Can be specified multiple times.")
-@click.option("-R","--dep-rem",multiple=True, nargs=2, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify dependencies to remove by listing first the type of relationship ('der', 'comp', or 'ver') followed by ID/alias of the target record. Can be specified multiple times.")
+@click.option("-A","--deps-add",multiple=True, nargs=2, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify dependencies to add by listing first the type of relationship ('der', 'comp', or 'ver') follwed by ID/alias of the target record. Can be specified multiple times.")
+@click.option("-R","--deps-rem",multiple=True, nargs=2, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify dependencies to remove by listing first the type of relationship ('der', 'comp', or 'ver') followed by ID/alias of the target record. Can be specified multiple times.")
 @_global_context_options
 @_global_output_options
-def _dataUpdate( data_id, title, alias, description, keywords, raw_data_file, extension, metadata, metadata_file, metadata_set, dep_clear, dep_add, dep_rem, context ):
+def _dataUpdate( data_id, title, alias, description, keywords, raw_data_file, extension, metadata, metadata_file, metadata_set, deps_add, deps_rem, context ):
     '''
     Update an existing data record. The data record ID is required and can be
     an ID, alias, or listing index; all other record attributes are optional.
@@ -675,11 +676,8 @@ def _dataUpdate( data_id, title, alias, description, keywords, raw_data_file, ex
     if metadata and metadata_file:
         raise Exception( "Cannot specify both --metadata and --metadata-file options." )
 
-    if dep_clear and dep_rem:
-        raise Exception( "Cannot specify both --dep-clear and --dep-rem options." )
-
     reply = _capi.dataUpdate( _resolve_id( data_id ), title = title, alias = alias, description = description, keywords = keywords, extension = extension,
-        metadata = metadata, metadata_file = metadata_file, metadata_set = metadata_set, dep_clear = dep_clear, dep_add = dep_add, dep_rem = dep_rem, context = context )
+        metadata = metadata, metadata_file = metadata_file, metadata_set = metadata_set, deps_add = deps_add, deps_rem = deps_rem, context = context )
     _generic_reply_handler( reply, _print_data )
 
     if raw_data_file:
@@ -720,8 +718,9 @@ def _dataDelete( data_id, force, context ):
 @click.argument("path", required=True, metavar="PATH", nargs=1)
 @click.option("-w","--wait",is_flag=True,help="Block until Globus transfer is complete.")
 @click.option("-e","--encrypt",type=click.Choice(['0', '1', '2']),default='1',help="Encryption mode: 0 = none, 1 = if available (default), 2 = force.")
+@click.option("-o","--orig_fname",is_flag=True,help="Download to original filename(s).")
 @_global_context_options
-def _dataGet( df_id, path, wait, encrypt, context ):
+def _dataGet( df_id, path, wait, encrypt, orig_fname, context ):
     '''
     Get (download) raw data of data records and/or collections. Multiple ID
     arguments can be specified and may be data record and/or collection IDs,
@@ -750,7 +749,7 @@ def _dataGet( df_id, path, wait, encrypt, context ):
     else:
         bar = None
 
-    reply = _capi.dataGet( resolved_ids, path, encrypt = int(encrypt), wait = wait, progress_bar = bar, context = context )
+    reply = _capi.dataGet( resolved_ids, path, encrypt = int(encrypt), orig_fname = orig_fname, wait = wait, progress_bar = bar, context = context )
 
     if reply[1] == "DataGetPutReply":
         _generic_reply_handler( reply, _print_task )
@@ -2184,7 +2183,7 @@ def _initialize( opts ):
     global _cur_ctx
     global _cur_coll
 
-    #print("_initialize, opts:",opts)
+    #print("_initialize, opts:", opts )
 
     if "version" in opts and opts["version"]:
         click.echo( version )
@@ -2195,12 +2194,13 @@ def _initialize( opts ):
         man_auth = opts["manual_auth"]
 
         if man_auth:
+            #print("CLI - manual auth")
             if _output_mode == _OM_RETN:
                 raise Exception("The --manual-auth option may not be used when running in API mode.")
             elif not _interactive:
                 raise Exception("The --manual-auth option may not be used when running non-interactively.")
 
-        _capi = CommandLib.API( **opts )
+        _capi = CommandLib.API( opts )
 
         if man_auth or _capi.getAuthUser() == None:
             if not man_auth:
@@ -2221,7 +2221,7 @@ def _initialize( opts ):
             i = 0
             while i < 3:
                 i += 1
-                uid = click.prompt("User ID: ")
+                uid = click.prompt("User ID")
                 password = getpass.getpass(prompt="Password: ")
                 try:
                     _capi.loginByPassword( uid, password )
