@@ -53,7 +53,12 @@ class API:
     # @param opts - Configuration options (optional)
     # @exception Exception: if invalid config values are present
     #
-    def __init__( self, opts = {}, **kwargs ):
+    def __init__( self, opts = {} ):
+        #print("CommandLib Init")
+
+        if not isinstance( opts, dict ):
+            raise Exception( "CommandLib API options parameter must be a dictionary." )
+
         self._uid = None
         self._cur_sel = None
         self._cur_ep = None
@@ -244,7 +249,7 @@ class API:
     # @param metadata - Domain-specific metadata (JSON object, optional)
     # @param metadata_file - Path to local file containing domain-specific metadata (JSON object, optional)
     # @param metadata_set - Set (replace) existing metadata with provided (default is merge)
-    # @param dep_clear - Clear existing dependencies
+    # @param deps - Set all dependencies (array of tuples of relation type and record ID)
     # @param deps_add - Dependencies to add (array of tuples of relation type and record ID)
     # @param deps_rem - Dependencies to remove (array of tuples of relation type and record ID)
     # @param context - User or project ID to use for alias resolution (optional)
@@ -252,15 +257,12 @@ class API:
     # @exception Exception: On invalid options or communication/server error
     #
     def dataUpdate( self, data_id, title = None, alias = None, description = None, keywords = None,
-        extension = None, metadata = None, metadata_file = None, metadata_set = False, dep_clear = False, dep_add = None,
-        dep_rem = None, context = None ):
+        extension = None, metadata = None, metadata_file = None, metadata_set = False, deps_add = None,
+        deps_rem = None, context = None ):
 
         if metadata and metadata_file:
             raise Exception( "Cannot specify both metadata and metadata-file options." )
 
-        if dep_clear and dep_rem:
-            raise Exception( "Cannot specify both dep-clear and dep-rem options." )
-
         msg = auth.RecordUpdateRequest()
         msg.id = self._resolve_id( data_id, context )
 
@@ -297,12 +299,9 @@ class API:
         if metadata_set:
             msg.mdset = True
 
-        if dep_clear:
-            msg.deps_clear = True
-
-        if dep_add:
-            for d in dep_add:
-                dep = msg.deps_add.add()
+        if deps_add:
+            for d in deps_add:
+                dep = msg.dep_add.add()
                 if d[0] == "der":
                     dep.type = 0
                 elif d[0] == "comp":
@@ -311,9 +310,9 @@ class API:
                     dep.type = 2
                 dep.id = self._resolve_id( d[1], context )
 
-        if dep_rem:
-            for d in dep_rem:
-                dep = msg.deps_rem.add()
+        if deps_rem:
+            for d in deps_rem:
+                dep = msg.dep_rem.add()
                 if d[0] == "der":
                     dep.type = 0
                 elif d[0] == "comp":
@@ -369,7 +368,7 @@ class API:
     # @exception Exception: If both Globus and HTTP transfers are required
     # @exception Exception: On invalid options or communication/server error
     #
-    def dataGet( self, item_id, path, encrypt = sdms.ENCRYPT_AVAIL, wait = False, timeout_sec = 0, progress_bar = None, context = None ):
+    def dataGet( self, item_id, path, encrypt = sdms.ENCRYPT_AVAIL, orig_fname = False, wait = False, timeout_sec = 0, progress_bar = None, context = None ):
         # Request server to map specified IDs into a list of specific record IDs.
         # This accounts for download of collections.
 
@@ -431,6 +430,7 @@ class API:
             msg.id.extend(glob_list)
             msg.path = self._resolvePathForGlobus( path, False )
             msg.encrypt = encrypt
+            msg.orig_fname = orig_fname
 
             reply = self._mapi.sendRecv( msg )
 
